@@ -64,6 +64,10 @@ def print_version(ctx, param, value):
     )
     for driver in drivers():
         msg += f"\n    [repr.attrib_name]{str(driver)}[/][dim]:[/][repr.number]{driver.version}[/][dim] from {driver.module}[/]"
+        if driver.required_collections:
+            msg += " requiring collections:"
+            for name, version in driver.required_collections.items():
+                msg += f" {name}>={version}"
     console.print(msg)
 
     ctx.exit()
