@@ -19,9 +19,9 @@
 #  DEALINGS IN THE SOFTWARE.
 
 import os
+from unittest.mock import call
 
 import pytest
-import sh
 
 from molecule import config, util
 from molecule.verifier import testinfra
@@ -60,25 +60,30 @@ def inventory_file(_instance):
     return _instance._config.provisioner.inventory_file
 
 
+@pytest.fixture
+def inventory_directory(_instance):
+    return _instance._config.provisioner.inventory_directory
+
+
 def test_config_private_member(_instance):
     assert isinstance(_instance._config, config.Config)
 
 
-def test_default_options_property(inventory_file, _instance):
+def test_default_options_property(inventory_directory, _instance):
     x = {
         "connection": "ansible",
-        "ansible-inventory": inventory_file,
+        "ansible-inventory": inventory_directory,
         "p": "no:cacheprovider",
     }
 
     assert x == _instance.default_options
 
 
-def test_default_options_property_updates_debug(inventory_file, _instance):
+def test_default_options_property_updates_debug(inventory_directory, _instance):
     _instance._config.args = {"debug": True}
     x = {
         "connection": "ansible",
-        "ansible-inventory": inventory_file,
+        "ansible-inventory": inventory_directory,
         "debug": True,
         "vvv": True,
         "p": "no:cacheprovider",
@@ -88,12 +93,12 @@ def test_default_options_property_updates_debug(inventory_file, _instance):
 
 
 def test_default_options_property_updates_sudo(
-    inventory_file, _instance, _patched_testinfra_get_tests
+    inventory_directory, _instance, _patched_testinfra_get_tests
 ):
     _instance._config.args = {"sudo": True}
     x = {
         "connection": "ansible",
-        "ansible-inventory": inventory_file,
+        "ansible-inventory": inventory_directory,
         "sudo": True,
         "p": "no:cacheprovider",
     }
@@ -163,10 +168,10 @@ def test_directory_property_overridden(_instance):
 
 
 @pytest.mark.parametrize("config_instance", ["_verifier_section_data"], indirect=True)
-def test_options_property(inventory_file, _instance):
+def test_options_property(inventory_directory, _instance):
     x = {
         "connection": "ansible",
-        "ansible-inventory": inventory_file,
+        "ansible-inventory": inventory_directory,
         "foo": "bar",
         "v": True,
         "verbose": True,
@@ -177,11 +182,11 @@ def test_options_property(inventory_file, _instance):
 
 
 @pytest.mark.parametrize("config_instance", ["_verifier_section_data"], indirect=True)
-def test_options_property_handles_cli_args(inventory_file, _instance):
+def test_options_property_handles_cli_args(inventory_directory, _instance):
     _instance._config.args = {"debug": True}
     x = {
         "connection": "ansible",
-        "ansible-inventory": inventory_file,
+        "ansible-inventory": inventory_directory,
         "foo": "bar",
         "debug": True,
         "vvv": True,
@@ -193,7 +198,7 @@ def test_options_property_handles_cli_args(inventory_file, _instance):
 
 
 @pytest.mark.parametrize("config_instance", ["_verifier_section_data"], indirect=True)
-def test_bake(_patched_testinfra_get_tests, inventory_file, _instance):
+def test_bake(_patched_testinfra_get_tests, inventory_directory, _instance):
     tests_directory = _instance._config.verifier.directory
     file1_file = os.path.join(tests_directory, "file1.py")
 
@@ -201,28 +206,29 @@ def test_bake(_patched_testinfra_get_tests, inventory_file, _instance):
     util.write_file(file1_file, "")
 
     _instance.bake()
-    x = [
-        str(sh.Command("pytest")),
-        "--ansible-inventory={}".format(inventory_file),
-        "--connection=ansible",
-        "-v",
-        "--foo=bar",
-        "foo.py",
-        "bar.py",
+    args = [
+        "pytest",
+        "--ansible-inventory",
+        inventory_directory,
+        "--connection",
+        "ansible",
+        "--foo",
+        "bar",
         "-p",
         "no:cacheprovider",
+        "foo.py",
+        "bar.py",
+        "-v",
         file1_file,
     ]
-    result = str(_instance._testinfra_command).split()
 
-    assert sorted(x) == sorted(result)
+    assert _instance._testinfra_command.cmd == args
 
 
 def test_execute(
     patched_logger_info,
     patched_run_command,
     _patched_testinfra_get_tests,
-    patched_logger_success,
     _instance,
 ):
     _instance._testinfra_command = "patched-command"
@@ -231,10 +237,9 @@ def test_execute(
     patched_run_command.assert_called_once_with("patched-command", debug=False)
 
     msg = "Executing Testinfra tests found in {}/...".format(_instance.directory)
-    patched_logger_info.assert_called_once_with(msg)
-
-    msg = "Verifier completed successfully."
-    patched_logger_success.assert_called_once_with(msg)
+    msg2 = "Verifier completed successfully."
+    calls = [call(msg), call(msg2)]
+    patched_logger_info.assert_has_calls(calls)
 
 
 def test_execute_does_not_execute(
@@ -268,10 +273,10 @@ def test_execute_bakes(patched_run_command, _patched_testinfra_get_tests, _insta
     assert 1 == patched_run_command.call_count
 
 
-def test_executes_catches_and_exits_return_code(
+def test_testinfra_executes_catches_and_exits_return_code(
     patched_run_command, _patched_testinfra_get_tests, _instance
 ):
-    patched_run_command.side_effect = sh.ErrorReturnCode_1(sh.pytest, b"", b"")
+    patched_run_command.side_effect = SystemExit(1)
     with pytest.raises(SystemExit) as e:
         _instance.execute()
 
